# ssc2ce-cpp
A set of C++ parsers for [ssc2ce](https://github.com/olned/ssc2ce-python)

This is more of a pilot project, if you have any wishes for adding exchanges or expanding functionality, please register issues.
